@@ -357,8 +357,8 @@ drive_button_update (gpointer user_data)
     g_free (display_name);
 
     /* base the icon size on the desired button size */
-    gtk_widget_size_request (GTK_WIDGET (self), &button_req);
-    gtk_widget_size_request (gtk_bin_get_child (GTK_BIN (self)), &image_req);
+    gtk_widget_get_preferred_size (GTK_WIDGET (self), NULL, &button_req);
+    gtk_widget_get_preferred_size (gtk_bin_get_child (GTK_BIN (self)), NULL, &image_req);
     width = self->icon_size - (button_req.width - image_req.width);
     height = self->icon_size - (button_req.height - image_req.height);
 
@@ -387,7 +387,7 @@ drive_button_update (gpointer user_data)
     gtk_image_set_from_pixbuf (GTK_IMAGE (gtk_bin_get_child (GTK_BIN (self))), pixbuf);
     g_object_unref (pixbuf);
 
-    gtk_widget_size_request (GTK_WIDGET (self), &button_req);
+    gtk_widget_get_preferred_size (GTK_WIDGET (self), NULL, &button_req);
 
     return FALSE;
 }
