@@ -314,7 +314,7 @@ properties_cb (GSimpleAction *action,
 	label = gtk_label_new (_(title));
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
 	gtk_box_pack_start (GTK_BOX (category_vbox), label, FALSE, FALSE, 0);
 	g_free (title);
 	
@@ -332,7 +332,7 @@ properties_cb (GSimpleAction *action,
 	gtk_widget_show (control_vbox);
 	
 	label = gtk_label_new_with_mnemonic (_("_Select a theme:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
 	gtk_box_pack_start (GTK_BOX (control_vbox), label, FALSE, FALSE, 0);
 
 	scrolled = gtk_scrolled_window_new (NULL, NULL);
