@@ -12,9 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -22,39 +20,21 @@
 #include "stickynotes_applet.h"
 #include "stickynotes_applet_callbacks.h"
 #include "stickynotes.h"
+#include "gsettings.h"
 
 #include <gtk/gtk.h>
 
 StickyNotes *stickynotes = NULL;
 
 /* Popup menu on the applet */
-static const GtkActionEntry stickynotes_applet_menu_actions[] =
-{
-	{ "new_note", GTK_STOCK_NEW, N_("_New Note"),
-	  NULL, NULL,
-	  G_CALLBACK (menu_new_note_cb) },
-	{ "hide_notes", NULL, N_("Hi_de Notes"),
-	  NULL, NULL,
-	  G_CALLBACK (menu_hide_notes_cb) },
-	{ "destroy_all", GTK_STOCK_DELETE, N_("_Delete Notes"),
-	  NULL, NULL,
-	  G_CALLBACK (menu_destroy_all_cb) },
-	{ "preferences", GTK_STOCK_PROPERTIES, N_("_Preferences"),
-	  NULL, NULL,
-	  G_CALLBACK (menu_preferences_cb) },
-	{ "help", GTK_STOCK_HELP, N_("_Help"),
-	  NULL, NULL,
-	  G_CALLBACK (menu_help_cb) },
-	{ "about", GTK_STOCK_ABOUT, N_("_About"),
-	  NULL, NULL,
-	  G_CALLBACK (menu_about_cb) }
-};
-
-static const GtkToggleActionEntry stickynotes_applet_menu_toggle_actions[] =
-{
-	{ "lock", NULL, N_("_Lock Notes"),
-	  NULL, NULL,
-	  G_CALLBACK (menu_toggle_lock_cb), FALSE }
+static const GActionEntry stickynotes_applet_menu_actions [] = {
+	{ "new-note",    menu_new_note_cb,    NULL, NULL,    NULL },
+	{ "hide-notes",  menu_hide_notes_cb,  NULL, NULL,    NULL },
+	{ "lock",        menu_toggle_lock_cb, NULL, "false", menu_toggle_lock_state },
+	{ "destroy-all", menu_destroy_all_cb, NULL, NULL,    NULL },
+	{ "preferences", menu_preferences_cb, NULL, NULL,    NULL },
+	{ "help",        menu_help_cb,        NULL, NULL,    NULL },
+	{ "about",       menu_about_cb,       NULL, NULL,    NULL }
 };
 
 /* Sticky Notes Icons */
@@ -141,6 +121,7 @@ stickynotes_applet_init (PanelApplet *panel_applet)
 
 	stickynotes->notes = NULL;
 	stickynotes->applets = NULL;
+	stickynotes->settings = panel_applet_settings_new (panel_applet, STICKYNOTES_SCHEMA);
 	stickynotes->last_timeout_data = 0;
 
 	g_set_application_name (_("Sticky Notes"));
@@ -164,21 +145,13 @@ stickynotes_applet_init (PanelApplet *panel_applet)
 			gdk_pixbuf_get_height (stickynotes->icon_normal));
 	stickynotes_make_prelight_icon (stickynotes->icon_prelight,
 			stickynotes->icon_normal, 30);
-	stickynotes->gconf = gconf_client_get_default();
 	stickynotes->visible = TRUE;
 
 	stickynotes_applet_init_icons();
 	stickynotes_applet_init_prefs();
 
-	/* Watch GConf values */
-	gconf_client_add_dir (stickynotes->gconf, GCONF_PATH,
-			GCONF_CLIENT_PRELOAD_NONE, NULL);
-	gconf_client_notify_add (stickynotes->gconf, GCONF_PATH "/defaults",
-			(GConfClientNotifyFunc) preferences_apply_cb,
-			NULL, NULL, NULL);
-	gconf_client_notify_add (stickynotes->gconf, GCONF_PATH "/settings",
-			(GConfClientNotifyFunc) preferences_apply_cb,
-			NULL, NULL, NULL);
+	g_signal_connect (stickynotes->settings, "changed",
+	                  G_CALLBACK (preferences_apply_cb), NULL);
 
 	/* Max height for large notes*/
 	stickynotes->max_height = 0.8*gdk_screen_get_height( gdk_screen_get_default() );
@@ -289,8 +262,7 @@ void stickynotes_applet_init_prefs(void)
 		g_object_unref(group);
 	}
 
-	if (!gconf_client_key_is_writable(stickynotes->gconf,
-				GCONF_PATH "/defaults/width", NULL))
+	if (!g_settings_is_writable (stickynotes->settings, KEY_DEFAULT_WIDTH))
 	{
 		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
 					stickynotes->builder, "width_label")),
@@ -299,8 +271,7 @@ void stickynotes_applet_init_prefs(void)
 					stickynotes->builder, "width_spin")),
 				FALSE);
 	}
-	if (!gconf_client_key_is_writable (stickynotes->gconf,
-				GCONF_PATH "/defaults/height", NULL))
+	if (!g_settings_is_writable (stickynotes->settings, KEY_DEFAULT_HEIGHT))
 	{
 		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
 					stickynotes->builder, "height_label")),
@@ -309,16 +280,14 @@ void stickynotes_applet_init_prefs(void)
 					stickynotes->builder, "height_spin")),
 				FALSE);
 	}
-	if (!gconf_client_key_is_writable (stickynotes->gconf,
-				GCONF_PATH "/defaults/color", NULL))
+	if (!g_settings_is_writable (stickynotes->settings, KEY_DEFAULT_COLOR))
 	{
 		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
 					stickynotes->builder, "prefs_color_label")),
 				FALSE);
 		gtk_widget_set_sensitive (stickynotes->w_prefs_color, FALSE);
 	}
-	if (!gconf_client_key_is_writable (stickynotes->gconf,
-				GCONF_PATH "/defaults/font_color", NULL))
+	if (!g_settings_is_writable (stickynotes->settings, KEY_DEFAULT_FONT_COLOR))
 	{
 		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
 					stickynotes->builder, "prefs_font_color_label")),
@@ -326,27 +295,22 @@ void stickynotes_applet_init_prefs(void)
 		gtk_widget_set_sensitive (stickynotes->w_prefs_font_color,
 				FALSE);
 	}
-	if (!gconf_client_key_is_writable (stickynotes->gconf,
-				GCONF_PATH "/settings/use_system_color", NULL))
+	if (!g_settings_is_writable (stickynotes->settings, KEY_USE_SYSTEM_COLOR))
 		gtk_widget_set_sensitive (stickynotes->w_prefs_sys_color,
 				FALSE);
-	if (!gconf_client_key_is_writable (stickynotes->gconf,
-				GCONF_PATH "/defaults/font", NULL))
+	if (!g_settings_is_writable (stickynotes->settings, KEY_DEFAULT_FONT))
 	{
 		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
 					stickynotes->builder, "prefs_font_label")),
 				FALSE);
 		gtk_widget_set_sensitive (stickynotes->w_prefs_font, FALSE);
 	}
-	if (!gconf_client_key_is_writable (stickynotes->gconf,
-				GCONF_PATH "/settings/use_system_font", NULL))
+	if (!g_settings_is_writable (stickynotes->settings, KEY_USE_SYSTEM_FONT))
 		gtk_widget_set_sensitive (stickynotes->w_prefs_sys_font,
 				FALSE);
-	if (!gconf_client_key_is_writable (stickynotes->gconf,
-				GCONF_PATH "/settings/sticky", NULL))
+	if (!g_settings_is_writable (stickynotes->settings, KEY_STICKY))
 		gtk_widget_set_sensitive (stickynotes->w_prefs_sticky, FALSE);
-	if (!gconf_client_key_is_writable (stickynotes->gconf,
-				GCONF_PATH "/settings/force_default", NULL))
+	if (!g_settings_is_writable (stickynotes->settings, KEY_FORCE_DEFAULT))
 		gtk_widget_set_sensitive (stickynotes->w_prefs_force, FALSE);
 
 	stickynotes_applet_update_prefs();
@@ -357,6 +321,7 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 {
 	AtkObject *atk_obj;
 	gchar *ui_path;
+	GAction *action;
 
 	/* Create Sticky Notes Applet */
 	StickyNotesApplet *applet = g_new(StickyNotesApplet, 1);
@@ -375,31 +340,26 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 
 	/* Add the applet icon */
 	gtk_container_add(GTK_CONTAINER(panel_applet), applet->w_image);
-	applet->panel_size = panel_applet_get_size (panel_applet);
 	applet->panel_orient = panel_applet_get_orient (panel_applet);
 	stickynotes_applet_update_icon(applet);
 
 	/* Add the popup menu */
-	applet->action_group = gtk_action_group_new ("StickyNotes Applet Actions");
-	gtk_action_group_set_translation_domain (applet->action_group, GETTEXT_PACKAGE);
-	gtk_action_group_add_actions (applet->action_group,
-				      stickynotes_applet_menu_actions,
-				      G_N_ELEMENTS (stickynotes_applet_menu_actions),
-				      applet);
-	gtk_action_group_add_toggle_actions (applet->action_group,
-					     stickynotes_applet_menu_toggle_actions,
-					     G_N_ELEMENTS (stickynotes_applet_menu_toggle_actions),
-					     applet);
+	applet->action_group = g_simple_action_group_new ();
+	g_action_map_add_action_entries (G_ACTION_MAP (applet->action_group),
+	                                 stickynotes_applet_menu_actions,
+	                                 G_N_ELEMENTS (stickynotes_applet_menu_actions),
+	                                 applet);
 	ui_path = g_build_filename (STICKYNOTES_MENU_UI_DIR, "stickynotes-applet-menu.xml", NULL);
-	panel_applet_setup_menu_from_file(panel_applet, ui_path, applet->action_group);
+	panel_applet_setup_menu_from_file(panel_applet, ui_path, applet->action_group, GETTEXT_PACKAGE);
 	g_free (ui_path);
 
-	if (panel_applet_get_locked_down (panel_applet)) {
-		GtkAction *action;
+	gtk_widget_insert_action_group (GTK_WIDGET (panel_applet), "stickynotes",
+	                                G_ACTION_GROUP (applet->action_group));
 
-		action = gtk_action_group_get_action (applet->action_group, "preferences");
-		gtk_action_set_visible (action, FALSE);
-	}
+	action = g_action_map_lookup_action (G_ACTION_MAP (applet->action_group), "preferences");
+	g_object_bind_property (panel_applet, "locked-down",
+	                        action, "enabled",
+	                        G_BINDING_DEFAULT|G_BINDING_INVERT_BOOLEAN|G_BINDING_SYNC_CREATE);
 
 	/* Connect all signals for applet management */
 	g_signal_connect(G_OBJECT(applet->w_applet), "button-press-event",
@@ -462,55 +422,46 @@ void stickynotes_applet_update_icon(StickyNotesApplet *applet)
 void
 stickynotes_applet_update_prefs (void)
 {
-	int height;
+	gint width, height;
 	gboolean sys_color, sys_font, sticky, force_default, desktop_hide;
 	char *font_str;
 	char *color_str, *font_color_str;
-	GdkColor color, font_color;
-
-	gint width = gconf_client_get_int(stickynotes->gconf,
-			GCONF_PATH "/defaults/width", NULL);
+	GdkRGBA color, font_color;
 
+	width = g_settings_get_int (stickynotes->settings, KEY_DEFAULT_WIDTH);
 	width = MAX (width, 1);
-	height = gconf_client_get_int (stickynotes->gconf,
-			GCONF_PATH "/defaults/height", NULL);
+
+	height = g_settings_get_int (stickynotes->settings, KEY_DEFAULT_HEIGHT);
 	height = MAX (height, 1);
 
-	sys_color = gconf_client_get_bool (stickynotes->gconf,
-			GCONF_PATH "/settings/use_system_color", NULL);
-	sys_font = gconf_client_get_bool (stickynotes->gconf,
-			GCONF_PATH "/settings/use_system_font", NULL);
-	sticky = gconf_client_get_bool (stickynotes->gconf,
-			GCONF_PATH "/settings/sticky", NULL);
-	force_default = gconf_client_get_bool (stickynotes->gconf,
-			GCONF_PATH "/settings/force_default", NULL);
-	font_str = gconf_client_get_string (stickynotes->gconf,
-			GCONF_PATH "/defaults/font", NULL);
-	desktop_hide = gconf_client_get_bool (stickynotes->gconf,
-			GCONF_PATH "/settings/desktop_hide", NULL);
+	sys_color = g_settings_get_boolean (stickynotes->settings, KEY_USE_SYSTEM_COLOR);
+	sys_font = g_settings_get_boolean (stickynotes->settings, KEY_USE_SYSTEM_FONT);
+	sticky = g_settings_get_boolean (stickynotes->settings, KEY_STICKY);
+	force_default = g_settings_get_boolean (stickynotes->settings, KEY_FORCE_DEFAULT);
+	desktop_hide = g_settings_get_boolean (stickynotes->settings, KEY_DESKTOP_HIDE);
 
-	if (!font_str)
-	{
+	font_str = g_settings_get_string (stickynotes->settings, KEY_DEFAULT_FONT);
+	if (IS_STRING_EMPTY (font_str)) {
+		g_free (font_str);
 		font_str = g_strdup ("Sans 10");
 	}
 
-	color_str = gconf_client_get_string (stickynotes->gconf,
-			GCONF_PATH "/defaults/color", NULL);
-	if (!color_str)
-	{
+	color_str = g_settings_get_string (stickynotes->settings, KEY_DEFAULT_COLOR);
+	if (IS_STRING_EMPTY (color_str)) {
+		g_free (color_str);
 		color_str = g_strdup ("#ECF833");
 	}
-	font_color_str = gconf_client_get_string (stickynotes->gconf,
-			GCONF_PATH "/defaults/font_color", NULL);
-	if (!font_color_str)
-	{
+
+	font_color_str = g_settings_get_string (stickynotes->settings, KEY_DEFAULT_FONT_COLOR);
+	if (IS_STRING_EMPTY (font_color_str)) {
+		g_free (font_color_str);
 		font_color_str = g_strdup ("#000000");
 	}
 
-	gdk_color_parse (color_str, &color);
+	gdk_rgba_parse (&color, color_str);
 	g_free (color_str);
 
-	gdk_color_parse (font_color_str, &font_color);
+	gdk_rgba_parse (&font_color, font_color_str);
 	g_free (font_color_str);
 
 	gtk_adjustment_set_value (stickynotes->w_prefs_width, width);
@@ -531,17 +482,13 @@ stickynotes_applet_update_prefs (void)
 			GTK_TOGGLE_BUTTON (stickynotes->w_prefs_desktop),
 			desktop_hide);
 
-	gtk_color_button_set_color (
-			GTK_COLOR_BUTTON (stickynotes->w_prefs_color), &color);
-	gtk_color_button_set_color (
-			GTK_COLOR_BUTTON (stickynotes->w_prefs_font_color),
-			&font_color);
+	gtk_color_button_set_rgba (GTK_COLOR_BUTTON (stickynotes->w_prefs_color), &color);
+	gtk_color_button_set_rgba (GTK_COLOR_BUTTON (stickynotes->w_prefs_font_color), &font_color);
 	gtk_font_button_set_font_name (
 			GTK_FONT_BUTTON (stickynotes->w_prefs_font), font_str);
 	g_free (font_str);
 
-	if (gconf_client_key_is_writable (stickynotes->gconf,
-				GCONF_PATH "/defaults/color", NULL))
+	if (g_settings_is_writable (stickynotes->settings, KEY_DEFAULT_COLOR))
 	{
 		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
 				stickynotes->builder, "prefs_color_label")),
@@ -549,8 +496,7 @@ stickynotes_applet_update_prefs (void)
 		gtk_widget_set_sensitive (stickynotes->w_prefs_color,
 				!sys_color);
 	}
-	if (gconf_client_key_is_writable (stickynotes->gconf,
-				GCONF_PATH "/defaults/prefs_font_color", NULL))
+	if (g_settings_is_writable (stickynotes->settings, KEY_DEFAULT_FONT_COLOR))
 	{
 		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
 				stickynotes->builder, "prefs_font_color_label")),
@@ -558,8 +504,7 @@ stickynotes_applet_update_prefs (void)
 		gtk_widget_set_sensitive (stickynotes->w_prefs_font_color,
 				!sys_color);
 	}
-	if (gconf_client_key_is_writable (stickynotes->gconf,
-				GCONF_PATH "/defaults/font", NULL))
+	if (g_settings_is_writable (stickynotes->settings, KEY_DEFAULT_FONT))
 	{
 		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
 				stickynotes->builder, "prefs_font_label")),
@@ -574,36 +519,24 @@ void stickynotes_applet_update_menus(void)
 	GList *l;
 	gboolean inconsistent = FALSE;
 
-	gboolean locked = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/locked", NULL);
-	gboolean locked_writable = gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/locked", NULL);
+	gboolean locked = g_settings_get_boolean (stickynotes->settings, KEY_LOCKED);
+	gboolean locked_writable = g_settings_is_writable (stickynotes->settings, KEY_LOCKED);
 
 	for (l = stickynotes->notes; l != NULL; l = l->next) {
 		StickyNote *note = l->data;
-
 		if (note->locked != locked) {
 			inconsistent = TRUE;
+
 			break;
 		}
 	}
 
 	for (l = stickynotes->applets; l != NULL; l = l->next) {
 		StickyNotesApplet *applet = l->data;
-		GSList *proxies, *p;
 
-		GtkAction *action = gtk_action_group_get_action (applet->action_group, "lock");
-
-		g_object_set (action,
-			      "active", locked,
-			      "sensitive", locked_writable,
-			      NULL);
-
-		proxies = gtk_action_get_proxies (action);
-		for (p = proxies; p; p = g_slist_next (p)) {
-			if (GTK_IS_CHECK_MENU_ITEM (p->data)) {
-				gtk_check_menu_item_set_inconsistent (GTK_CHECK_MENU_ITEM (p->data),
-								      inconsistent);
-			}
-		}
+		GSimpleAction *action = (GSimpleAction *) g_action_map_lookup_action (G_ACTION_MAP (applet->action_group), "lock");
+		g_simple_action_set_enabled (action, locked_writable);
+		g_simple_action_set_state (action, g_variant_new_boolean (locked));
 	}
 }
 
@@ -647,7 +580,7 @@ stickynotes_applet_panel_icon_get_geometry (int *x, int *y, int *width, int *hei
 
 	widget = GTK_WIDGET (applet->w_image);
 
-	gtk_widget_size_request (widget, &requisition);
+	gtk_widget_get_preferred_size (widget, NULL, &requisition);
 
 	gdk_window_get_origin (gtk_widget_get_window (widget), x, y);
 
