@@ -17,8 +17,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -30,12 +29,10 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#include <gconf/gconf-client.h>
 #include <gio/gio.h>
 #include <panel-applet.h>
 
 #include "trash-empty.h"
-#include "xstuff.h"
 
 typedef PanelAppletClass TrashAppletClass;
 
@@ -57,28 +54,24 @@ G_DEFINE_TYPE (TrashApplet, trash_applet, PANEL_TYPE_APPLET);
 #define TRASH_APPLET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
                            TRASH_TYPE_APPLET, TrashApplet))
 
-static void trash_applet_do_empty    (GtkAction   *action,
-                                      TrashApplet *applet);
-static void trash_applet_show_about  (GtkAction   *action,
-                                      TrashApplet *applet);
-static void trash_applet_open_folder (GtkAction   *action,
-                                      TrashApplet *applet);
-static void trash_applet_show_help   (GtkAction   *action,
-                                      TrashApplet *applet);
+static void trash_applet_do_empty    (GSimpleAction *action,
+                                      GVariant      *parameter,
+                                      gpointer       user_data);
+static void trash_applet_show_about  (GSimpleAction *action,
+                                      GVariant      *parameter,
+                                      gpointer       user_data);
+static void trash_applet_open_folder (GSimpleAction *action,
+                                      GVariant      *parameter,
+                                      gpointer       user_data);
+static void trash_applet_show_help   (GSimpleAction *action,
+                                      GVariant      *parameter,
+                                      gpointer       user_data);
 
-static const GtkActionEntry trash_applet_menu_actions [] = {
-	{ "EmptyTrash", GTK_STOCK_CLEAR, N_("_Empty Trash"),
-	  NULL, NULL,
-	  G_CALLBACK (trash_applet_do_empty) },
-	{ "OpenTrash", GTK_STOCK_OPEN, N_("_Open Trash"),
-	  NULL, NULL,
-	  G_CALLBACK (trash_applet_open_folder) },
-	{ "HelpTrash", GTK_STOCK_HELP, N_("_Help"),
-	  NULL, NULL,
-	  G_CALLBACK (trash_applet_show_help) },
-	{ "AboutTrash", GTK_STOCK_ABOUT, N_("_About"),
-	  NULL, NULL,
-	  G_CALLBACK (trash_applet_show_about) }
+static const GActionEntry trash_applet_menu_actions [] = {
+	{ "open",  trash_applet_open_folder, NULL, NULL, NULL },
+	{ "empty", trash_applet_do_empty,    NULL, NULL, NULL },
+	{ "help",  trash_applet_show_help,   NULL, NULL, NULL },
+	{ "about", trash_applet_show_about,   NULL, NULL, NULL }
 };
 
 static void
@@ -244,23 +237,15 @@ trash_applet_init (TrashApplet *applet)
   trash_applet_monitor_changed (applet);
 }
 
-#define PANEL_ENABLE_ANIMATIONS "/apps/panel/global/enable_animations"
 static gboolean
 trash_applet_button_release (GtkWidget      *widget,
                              GdkEventButton *event)
 {
   TrashApplet *applet = TRASH_APPLET (widget);
-  static GConfClient *client;
-
-  if (client == NULL)
-    client = gconf_client_get_default ();
 
   if (event->button == 1)
     {
-      if (gconf_client_get_bool (client, PANEL_ENABLE_ANIMATIONS, NULL))
-        xstuff_zoom_animate (widget, NULL);
-
-      trash_applet_open_folder (NULL, applet);
+      trash_applet_open_folder (NULL, NULL, applet);
 
       return TRUE;
     }
@@ -285,7 +270,7 @@ trash_applet_key_press (GtkWidget   *widget,
      case GDK_KEY_Return:
      case GDK_KEY_space:
      case GDK_KEY_KP_Space:
-      trash_applet_open_folder (NULL, applet);
+      trash_applet_open_folder (NULL, NULL, applet);
       return TRUE;
 
      default:
@@ -356,16 +341,20 @@ error_dialog (TrashApplet *applet, const gchar *error, ...)
 }
 
 static void
-trash_applet_do_empty (GtkAction   *action,
-                       TrashApplet *applet)
+trash_applet_do_empty (GSimpleAction *action,
+                       GVariant      *parameter,
+                       gpointer       user_data)
 {
+  TrashApplet *applet = (TrashApplet *) user_data;
   trash_empty (GTK_WIDGET (applet));
 }
 
 static void
-trash_applet_open_folder (GtkAction   *action,
-                          TrashApplet *applet)
+trash_applet_open_folder (GSimpleAction *action,
+                          GVariant      *parameter,
+                          gpointer       user_data)
 {
+  TrashApplet *applet = (TrashApplet *) user_data;
   GError *err = NULL;
 
   gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (applet)),
@@ -382,9 +371,11 @@ trash_applet_open_folder (GtkAction   *action,
 }
 
 static void
-trash_applet_show_help (GtkAction   *action,
-                        TrashApplet *applet)
+trash_applet_show_help (GSimpleAction *action,
+                        GVariant      *parameter,
+                        gpointer       user_data)
 {
+  TrashApplet *applet = (TrashApplet *) user_data;
   GError *err = NULL;
 
   /* FIXME - Actually, we need a user guide */
@@ -404,8 +395,9 @@ trash_applet_show_help (GtkAction   *action,
 
 
 static void
-trash_applet_show_about (GtkAction   *action,
-                         TrashApplet *applet)
+trash_applet_show_about (GSimpleAction *action,
+                         GVariant      *parameter,
+                         gpointer       user_data)
 {
   static const char *authors[] = {
     "Michiel Sikkes <michiel@eyesopened.nl>",
@@ -460,19 +452,19 @@ confirm_delete_immediately (GtkWidget *parent_view,
 
   gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 14);
 
-  hbox = gtk_hbox_new (FALSE, 12);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
   gtk_widget_show (hbox);
   gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), hbox,
                       FALSE, FALSE, 0);
 
-  image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_QUESTION,
-                                    GTK_ICON_SIZE_DIALOG);
-  gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
+  image = gtk_image_new_from_icon_name ("dialog-question", GTK_ICON_SIZE_DIALOG);
+  gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
+  gtk_widget_set_valign (image, GTK_ALIGN_START);
   gtk_widget_show (image);
   gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 
-  vbox = gtk_vbox_new (FALSE, 12);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
   gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
   gtk_widget_show (vbox);
 
@@ -493,7 +485,7 @@ confirm_delete_immediately (GtkWidget *parent_view,
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-  gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
   g_free (str);
@@ -501,14 +493,14 @@ confirm_delete_immediately (GtkWidget *parent_view,
   label = gtk_label_new (detail);
   gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-  gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
   g_free (detail);
 
-  gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL,
+  gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Cancel"),
                          GTK_RESPONSE_CANCEL);
-  gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_DELETE,
+  gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Delete"),
                          GTK_RESPONSE_YES);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog),
                                    GTK_RESPONSE_YES);
@@ -610,7 +602,7 @@ trash_applet_factory (PanelApplet *applet,
 
   if (!strcmp (iid, "TrashApplet"))
     {
-      GtkActionGroup *action_group;
+      GSimpleActionGroup *action_group;
       gchar          *ui_path;
 
       g_set_application_name (_("Trash Applet"));
@@ -618,15 +610,18 @@ trash_applet_factory (PanelApplet *applet,
       gtk_window_set_default_icon_name ("user-trash");
 
       /* Set up the menu */
-      action_group = gtk_action_group_new ("Trash Applet Actions");
-      gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
-      gtk_action_group_add_actions (action_group,
-				    trash_applet_menu_actions,
-				    G_N_ELEMENTS (trash_applet_menu_actions),
-				    applet);
+      action_group = g_simple_action_group_new ();
+      g_action_map_add_action_entries (G_ACTION_MAP (action_group),
+                                       trash_applet_menu_actions,
+                                       G_N_ELEMENTS (trash_applet_menu_actions),
+                                       applet);
       ui_path = g_build_filename (TRASH_MENU_UI_DIR, "trashapplet-menu.xml", NULL);
-      panel_applet_setup_menu_from_file (applet, ui_path, action_group);
+      panel_applet_setup_menu_from_file (applet, ui_path, action_group, GETTEXT_PACKAGE);
       g_free (ui_path);
+
+      gtk_widget_insert_action_group (GTK_WIDGET (applet), "trash",
+                                      G_ACTION_GROUP (action_group));
+
       g_object_unref (action_group);
 
       gtk_widget_show (GTK_WIDGET (applet));
